==> mongodb-6.0.22.gh.tar.gz: mongo-r6.0.22/src/mongo/db/pipeline/document_source_query_stats_validators.cpp <==
/**
 *    Copyright (C) 2021-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/pipeline/document_source_query_stats_validators.h"
#include "mongo/db/query/query_stats/transform_algorithm_gen.h"
#include "mongo/util/str.h"
#include <set>

namespace mongo {

Status validateAlgo(TransformAlgorithmEnum algorithm) {
    if (algorithm == TransformAlgorithmEnum::kNone) {
        return {ErrorCodes::FailedToParse,
                str::stream() << "Algorithm specified but found no valid algorithm"};
    }
    return Status::OK();
}

Status validateHmac(std::vector<uint8_t> hmacKey) {
    if (hmacKey.size() < 32) {
        return {ErrorCodes::BadValue,
                str::stream() << "hmacKey must be greater than or equal to 32 bytes, found length: "
                              << hmacKey.size()};
    }
    // length check
    return Status::OK();
}
}  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/db/pipeline/document_source_query_stats_validators.cpp <==
/**
 *    Copyright (C) 2021-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/db/pipeline/document_source_query_stats_validators.h"
#include "mongo/base/error_codes.h"
#include "mongo/db/query/query_stats/transform_algorithm_gen.h"
#include "mongo/util/str.h"

namespace mongo {

Status validateAlgo(TransformAlgorithmEnum algorithm) {
    if (algorithm == TransformAlgorithmEnum::kNone) {
        return {ErrorCodes::FailedToParse,
                str::stream() << "Algorithm specified but found no valid algorithm"};
    }
    return Status::OK();
}

Status validateHmac(std::vector<uint8_t> hmacKey) {
    if (hmacKey.size() < 32) {
        return {ErrorCodes::BadValue,
                str::stream() << "hmacKey must be greater than or equal to 32 bytes, found length: "
                              << hmacKey.size()};
    }
    // length check
    return Status::OK();
}
}  // namespace mongo
